package com.pdflib.cookbook.pcos.pages;

import com.pdflib.IpCOS;
import com.pdflib.cookbook.pcos.pcos_cookbook_example;

/**
 * Create a list of all blocks contained on the pages of a PDF document and show
 * their name, type and dimensions.
 * <p>
 * Required software: pCOS interface 3 (pCOS 3.x, PDFlib+PDI/PPS 7.x, TET 2.2,
 * PLOP 3.x) <br>
 * Required data: PDF document
 * 
 * @version $Id: blocks.java,v 1.8 2015/11/16 11:53:16 stm Exp $
 */
public class blocks extends pcos_cookbook_example {

    /* This is where the data files are. Adjust as necessary. */
    private final static String SEARCH_PATH = "../input";

    public void example_code(IpCOS p, int doc) throws Exception {

        System.out.println("File name: " + p.pcos_get_string(doc, "filename"));

        int pagecount = (int) p.pcos_get_number(doc, "length:pages");

        for (int page = 0; page < pagecount; page++) {
            String objtype = p.pcos_get_string(doc, "type:pages[" + page
                + "]/blocks");
            if (objtype.equals("null"))
                continue;

            int blockcount = (int) p.pcos_get_number(doc, "length:pages["
                + page + "]/blocks");
            if (blockcount == 0)
                continue;
            else
                System.out.println("Blocks on page " + (page + 1) + ":");

            for (int b = 0; b < blockcount; b++) {
                String val = p.pcos_get_string(doc, "pages[" + page + "]"
                    + "/blocks[" + b + "]/Subtype");

                System.out.print(val + " Block ");

                val = p.pcos_get_string(doc, "pages[" + page + "]"
                    + "/blocks[" + b + "]/Name");
                System.out.println("'" + val + "':");

                for (int j = 0; j < 4; j++) {
                    System.out.print(p.pcos_get_number(doc, "pages[" + page + "]"
                        + "/blocks[" + b + "]/Rect[" + j + "]")
                        + " ");
                }
                System.out.println();
            }
        }
    }

    public blocks(String[] argv, String readable_name, String search_path,
        String full_rcs_file_name, String revision) {
        super(argv, readable_name, search_path, full_rcs_file_name, revision);
    }

    public static void main(String argv[]) {
        blocks example = new blocks(argv, "PDFlib Blocks", SEARCH_PATH,
            "$RCSfile: blocks.java,v $", "$Revision: 1.8 $");
        example.execute();
    }
}
