package com.pdflib.cookbook.pcos.pages;

import com.pdflib.IpCOS;
import com.pdflib.cookbook.pcos.pcos_cookbook_example;

/**
 * Print information about all images in the document.
 * <p>
 * Required software: pCOS interface 3 (pCOS 3.x, PDFlib+PDI/PPS 7.x, TET 2.2,
 * PLOP 3.x) <br>
 * Required data: PDF document
 * 
 * @version $Id: page_images.java,v 1.6 2015/11/16 11:53:16 stm Exp $
 */
public class page_images extends pcos_cookbook_example {

    /* This is where the data files are. Adjust as necessary. */
    private final static String SEARCH_PATH = "../input";

    public void example_code(IpCOS p, int doc) throws Exception {

        System.out.println("File name: " + p.pcos_get_string(doc, "filename"));

        int imagecount = 0;
        int pagecount = (int) p.pcos_get_number(doc, "length:pages");

        for (int page = 0; page < pagecount; page += 1) {
            imagecount += print_page_image_info(p, doc, page);
        }

        System.out.println("Image count: " + imagecount);
    }

    private int print_page_image_info(IpCOS p, int doc, int page)
        throws Exception {
        int images_on_page = (int) p.pcos_get_number(doc, "length:pages["
            + page + "]/images");
        if (images_on_page > 0) {
            System.out.println("Page " + (page + 1));
            for (int image = 0; image < images_on_page; image += 1) {
                System.out.print("  Image " + (image + 1) + ", ");

                String objtype = p.pcos_get_string(doc, "type:pages[" + page
                    + "]/images[" + image + "]/Filter");

                if (objtype.equals("name")) {
                    String filter = p.pcos_get_string(doc, "pages[" + page
                        + "]/images[" + image + "]/Filter");
                    System.out.print("Filter=" + filter);
                }
                else if (objtype.equals("array")) {
                    String filter = p.pcos_get_string(doc, "pages[" + page
                        + "]/images[" + image + "]/Filter[0]");
                    System.out.print("Filter=" + filter);

                    int filtercount = (int) p.pcos_get_number(doc,
                        "length:pages[" + page + "]/images[" + image
                            + "]/Filter");

                    for (int f = 1; f < filtercount; f++) {
                        filter = p.pcos_get_string(doc, "pages[" + page
                            + "]/images[" + image + "]/Filter[" + f + "]");
                        System.out.print("+" + filter);
                    }
                }

                System.out.print(", "
                    + (int) p.pcos_get_number(doc, "pages[" + page
                        + "]/images[" + image + "]/Width")
                    + "x"
                    + (int) p.pcos_get_number(doc, "pages[" + page
                        + "]/images[" + image + "]/Height") + ", ");

                check_colorspace(p, doc, page, image);

                System.out.println();
            }
        }
        return images_on_page;
    }

    private static void check_colorspace(IpCOS p, int doc, int page, int image)
        throws Exception {
        String objtype = p.pcos_get_string(doc, "type:pages[" + page
            + "]/images[" + image + "]/ColorSpace");

        if (objtype.equals("name")) {
            System.out.print(p.pcos_get_string(doc, "pages[" + page
                + "]/images[" + image + "]/ColorSpace"));
        }
        else if (objtype.equals("array")) {
            String cs = p.pcos_get_string(doc, "pages[" + page + "]/images["
                + image + "]/ColorSpace[0]");
            System.out.print(cs);

            if (cs.equals("Indexed") || cs.equals("Separation")) {
                System.out.print(" "
                    + p.pcos_get_string(doc, "pages[" + page + "]/images["
                        + image + "]/ColorSpace[1]"));
            }
        }
        else if (objtype.equals("null")) {
            System.out.print("ImageMask");
        }
        else {
            System.out.print("(complex ColorSpace)");
        }
    }

    public page_images(String[] argv, String readable_name, String search_path,
        String full_rcs_file_name, String revision) {
        super(argv, readable_name, search_path, full_rcs_file_name, revision);
    }

    public static void main(String argv[]) {
        page_images example = new page_images(argv, "Image XObjects",
            SEARCH_PATH, "$RCSfile: page_images.java,v $", "$Revision: 1.6 $");
        example.execute();
    }
}
